# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dynamic/interfaces/feed/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.dynamic.common import dynamic_pb2 as bilibili_dot_dynamic_dot_common_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-bilibili/dynamic/interfaces/feed/v1/api.proto\x12\x1d\x62ilibili.main.dynamic.feed.v1\x1a%bilibili/dynamic/common/dynamic.proto\"\xf0\x04\n\x0c\x43reateDynReq\x12.\n\x04meta\x18\x01 \x01(\x0b\x32 .bilibili.dynamic.UserCreateMeta\x12\x30\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1f.bilibili.dynamic.CreateContent\x12,\n\x05scene\x18\x03 \x01(\x0e\x32\x1d.bilibili.dynamic.CreateScene\x12)\n\x04pics\x18\x04 \x03(\x0b\x32\x1b.bilibili.dynamic.CreatePic\x12\x31\n\nrepost_src\x18\x05 \x01(\x0b\x32\x1d.bilibili.dynamic.DynIdentity\x12/\n\x05video\x18\x06 \x01(\x0b\x32 .bilibili.dynamic.CreateDynVideo\x12\x13\n\x0bsketch_type\x18\x07 \x01(\x03\x12(\n\x06sketch\x18\x08 \x01(\x0b\x32\x18.bilibili.dynamic.Sketch\x12*\n\x07program\x18\t \x01(\x0b\x32\x19.bilibili.dynamic.Program\x12,\n\x07\x64yn_tag\x18\n \x01(\x0b\x32\x1b.bilibili.dynamic.CreateTag\x12\x37\n\x0b\x61ttach_card\x18\x0b \x01(\x0b\x32\".bilibili.dynamic.CreateAttachCard\x12.\n\x06option\x18\x0c \x01(\x0b\x32\x1e.bilibili.dynamic.CreateOption\x12,\n\x05topic\x18\r \x01(\x0b\x32\x1d.bilibili.dynamic.CreateTopic\x12\x11\n\tupload_id\x18\x0e \x01(\t\"\x84\x01\n\x12\x43reateInitCheckReq\x12\r\n\x05scene\x18\x01 \x01(\x05\x12,\n\x04meta\x18\x02 \x01(\x0b\x32\x1e.bilibili.dynamic.MetaDataCtrl\x12\x31\n\x06repost\x18\x03 \x01(\x0b\x32!.bilibili.dynamic.RepostInitCheck\"&\n\x12\x43reatePageInfosReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\"W\n\x12\x43reatePageInfosRsp\x12\x41\n\x05topic\x18\x01 \x01(\x0b\x32\x32.bilibili.main.dynamic.feed.v1.CreatePageTopicInfo\";\n\x13\x43reatePageTopicInfo\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\"h\n\x1e\x43reatePermissionButtonClickReq\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.bilibili.main.dynamic.feed.v1.DynamicButtonClickBizType\" \n\x1e\x43reatePermissionButtonClickRsp\"\x1a\n\x18\x43reatePlusButtonClickReq\"\x1a\n\x18\x43reatePlusButtonClickRsp\"\x17\n\x15\x44ynamicButtonClickReq\"\x17\n\x15\x44ynamicButtonClickRsp\"\x0e\n\x0cHotSearchReq\"w\n\x0cHotSearchRsp\x12?\n\x05items\x18\x01 \x03(\x0b\x32\x30.bilibili.main.dynamic.feed.v1.HotSearchRsp.Item\x12\x0f\n\x07version\x18\x02 \x01(\t\x1a\x15\n\x04Item\x12\r\n\x05words\x18\x01 \x01(\t\"\x98\x01\n\x15ReserveButtonClickReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x12\n\nreserve_id\x18\x02 \x01(\x03\x12\x15\n\rreserve_total\x18\x03 \x01(\x03\x12\x16\n\x0e\x63ur_btn_status\x18\x04 \x01(\x05\x12\r\n\x05spmid\x18\x05 \x01(\t\x12\x0e\n\x06\x64yn_id\x18\x06 \x01(\x03\x12\x10\n\x08\x64yn_type\x18\x07 \x01(\x03\"\x92\x02\n\x16ReserveButtonClickResp\x12L\n\x10\x66inal_btn_status\x18\x01 \x01(\x0e\x32\x32.bilibili.main.dynamic.feed.v1.ReserveButtonStatus\x12\x42\n\x08\x62tn_mode\x18\x02 \x01(\x0e\x32\x30.bilibili.main.dynamic.feed.v1.ReserveButtonMode\x12\x16\n\x0ereserve_update\x18\x03 \x01(\x03\x12\x13\n\x0b\x64\x65sc_update\x18\x04 \x01(\t\x12\x14\n\x0chas_activity\x18\x05 \x01(\x08\x12\x14\n\x0c\x61\x63tivity_url\x18\x06 \x01(\t\x12\r\n\x05toast\x18\x07 \x01(\t\"m\n\x0eSubmitCheckReq\x12\x30\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1f.bilibili.dynamic.CreateContent\x12)\n\x04pics\x18\x02 \x03(\x0b\x32\x1b.bilibili.dynamic.CreatePic\"\x10\n\x0eSubmitCheckRsp\"%\n\nSuggestReq\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\"=\n\nSuggestRsp\x12\x0c\n\x04list\x18\x01 \x03(\t\x12\x10\n\x08track_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t*\x95\x01\n\x19\x44ynamicButtonClickBizType\x12&\n\"DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE\x10\x00\x12&\n\"DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE\x10\x01\x12(\n$DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP\x10\x02*u\n\x11ReserveButtonMode\x12\x1c\n\x18RESERVE_BUTTON_MODE_NONE\x10\x00\x12\x1f\n\x1bRESERVE_BUTTON_MODE_RESERVE\x10\x01\x12!\n\x1dRESERVE_BUTTON_MODE_UP_CANCEL\x10\x02*y\n\x13ReserveButtonStatus\x12\x1e\n\x1aRESERVE_BUTTON_STATUS_NONE\x10\x00\x12!\n\x1dRESERVE_BUTTON_STATUS_UNCHECK\x10\x01\x12\x1f\n\x1bRESERVE_BUTTON_STATUS_CHECK\x10\x02\x32\x88\x0b\n\x04\x46\x65\x65\x64\x12g\n\x0f\x43reateInitCheck\x12\x31.bilibili.main.dynamic.feed.v1.CreateInitCheckReq\x1a!.bilibili.dynamic.CreateCheckResp\x12k\n\x0bSubmitCheck\x12-.bilibili.main.dynamic.feed.v1.SubmitCheckReq\x1a-.bilibili.main.dynamic.feed.v1.SubmitCheckRsp\x12V\n\tCreateDyn\x12+.bilibili.main.dynamic.feed.v1.CreateDynReq\x1a\x1c.bilibili.dynamic.CreateResp\x12T\n\x0cGetUidByName\x12!.bilibili.dynamic.GetUidByNameReq\x1a!.bilibili.dynamic.GetUidByNameRsp\x12\x42\n\x06\x41tList\x12\x1b.bilibili.dynamic.AtListReq\x1a\x1b.bilibili.dynamic.AtListRsp\x12\x46\n\x08\x41tSearch\x12\x1d.bilibili.dynamic.AtSearchReq\x1a\x1b.bilibili.dynamic.AtListRsp\x12\x81\x01\n\x12ReserveButtonClick\x12\x34.bilibili.main.dynamic.feed.v1.ReserveButtonClickReq\x1a\x35.bilibili.main.dynamic.feed.v1.ReserveButtonClickResp\x12\x89\x01\n\x15\x43reatePlusButtonClick\x12\x37.bilibili.main.dynamic.feed.v1.CreatePlusButtonClickReq\x1a\x37.bilibili.main.dynamic.feed.v1.CreatePlusButtonClickRsp\x12\x65\n\tHotSearch\x12+.bilibili.main.dynamic.feed.v1.HotSearchReq\x1a+.bilibili.main.dynamic.feed.v1.HotSearchRsp\x12_\n\x07Suggest\x12).bilibili.main.dynamic.feed.v1.SuggestReq\x1a).bilibili.main.dynamic.feed.v1.SuggestRsp\x12\x80\x01\n\x12\x44ynamicButtonClick\x12\x34.bilibili.main.dynamic.feed.v1.DynamicButtonClickReq\x1a\x34.bilibili.main.dynamic.feed.v1.DynamicButtonClickRsp\x12\x9b\x01\n\x1b\x43reatePermissionButtonClick\x12=.bilibili.main.dynamic.feed.v1.CreatePermissionButtonClickReq\x1a=.bilibili.main.dynamic.feed.v1.CreatePermissionButtonClickRsp\x12w\n\x0f\x43reatePageInfos\x12\x31.bilibili.main.dynamic.feed.v1.CreatePageInfosReq\x1a\x31.bilibili.main.dynamic.feed.v1.CreatePageInfosRspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dynamic.interfaces.feed.v1.api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DYNAMICBUTTONCLICKBIZTYPE']._serialized_start=2118
  _globals['_DYNAMICBUTTONCLICKBIZTYPE']._serialized_end=2267
  _globals['_RESERVEBUTTONMODE']._serialized_start=2269
  _globals['_RESERVEBUTTONMODE']._serialized_end=2386
  _globals['_RESERVEBUTTONSTATUS']._serialized_start=2388
  _globals['_RESERVEBUTTONSTATUS']._serialized_end=2509
  _globals['_CREATEDYNREQ']._serialized_start=120
  _globals['_CREATEDYNREQ']._serialized_end=744
  _globals['_CREATEINITCHECKREQ']._serialized_start=747
  _globals['_CREATEINITCHECKREQ']._serialized_end=879
  _globals['_CREATEPAGEINFOSREQ']._serialized_start=881
  _globals['_CREATEPAGEINFOSREQ']._serialized_end=919
  _globals['_CREATEPAGEINFOSRSP']._serialized_start=921
  _globals['_CREATEPAGEINFOSRSP']._serialized_end=1008
  _globals['_CREATEPAGETOPICINFO']._serialized_start=1010
  _globals['_CREATEPAGETOPICINFO']._serialized_end=1069
  _globals['_CREATEPERMISSIONBUTTONCLICKREQ']._serialized_start=1071
  _globals['_CREATEPERMISSIONBUTTONCLICKREQ']._serialized_end=1175
  _globals['_CREATEPERMISSIONBUTTONCLICKRSP']._serialized_start=1177
  _globals['_CREATEPERMISSIONBUTTONCLICKRSP']._serialized_end=1209
  _globals['_CREATEPLUSBUTTONCLICKREQ']._serialized_start=1211
  _globals['_CREATEPLUSBUTTONCLICKREQ']._serialized_end=1237
  _globals['_CREATEPLUSBUTTONCLICKRSP']._serialized_start=1239
  _globals['_CREATEPLUSBUTTONCLICKRSP']._serialized_end=1265
  _globals['_DYNAMICBUTTONCLICKREQ']._serialized_start=1267
  _globals['_DYNAMICBUTTONCLICKREQ']._serialized_end=1290
  _globals['_DYNAMICBUTTONCLICKRSP']._serialized_start=1292
  _globals['_DYNAMICBUTTONCLICKRSP']._serialized_end=1315
  _globals['_HOTSEARCHREQ']._serialized_start=1317
  _globals['_HOTSEARCHREQ']._serialized_end=1331
  _globals['_HOTSEARCHRSP']._serialized_start=1333
  _globals['_HOTSEARCHRSP']._serialized_end=1452
  _globals['_HOTSEARCHRSP_ITEM']._serialized_start=1431
  _globals['_HOTSEARCHRSP_ITEM']._serialized_end=1452
  _globals['_RESERVEBUTTONCLICKREQ']._serialized_start=1455
  _globals['_RESERVEBUTTONCLICKREQ']._serialized_end=1607
  _globals['_RESERVEBUTTONCLICKRESP']._serialized_start=1610
  _globals['_RESERVEBUTTONCLICKRESP']._serialized_end=1884
  _globals['_SUBMITCHECKREQ']._serialized_start=1886
  _globals['_SUBMITCHECKREQ']._serialized_end=1995
  _globals['_SUBMITCHECKRSP']._serialized_start=1997
  _globals['_SUBMITCHECKRSP']._serialized_end=2013
  _globals['_SUGGESTREQ']._serialized_start=2015
  _globals['_SUGGESTREQ']._serialized_end=2052
  _globals['_SUGGESTRSP']._serialized_start=2054
  _globals['_SUGGESTRSP']._serialized_end=2115
  _globals['_FEED']._serialized_start=2512
  _globals['_FEED']._serialized_end=3928
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AdInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATIVE_ID_FIELD_NUMBER: builtins.int
    CREATIVE_TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    CREATIVE_CONTENT_FIELD_NUMBER: builtins.int
    AD_CB_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    IS_AD_FIELD_NUMBER: builtins.int
    CM_MARK_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    IS_AD_LOC_FIELD_NUMBER: builtins.int
    CARD_INDEX_FIELD_NUMBER: builtins.int
    CLIENT_IP_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CREATIVE_STYLE_FIELD_NUMBER: builtins.int
    creative_id: builtins.int
    """"""
    creative_type: builtins.int
    """"""
    card_type: builtins.int
    """"""
    @property
    def creative_content(self) -> global___CreativeContent:
        """"""
    ad_cb: builtins.str
    """"""
    resource: builtins.int
    """"""
    source: builtins.int
    """"""
    request_id: builtins.str
    """"""
    is_ad: builtins.bool
    """"""
    cm_mark: builtins.int
    """"""
    index: builtins.int
    """"""
    is_ad_loc: builtins.bool
    """"""
    card_index: builtins.int
    """"""
    client_ip: builtins.str
    """"""
    extra: builtins.bytes
    """"""
    creative_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        creative_id: builtins.int = ...,
        creative_type: builtins.int = ...,
        card_type: builtins.int = ...,
        creative_content: global___CreativeContent | None = ...,
        ad_cb: builtins.str = ...,
        resource: builtins.int = ...,
        source: builtins.int = ...,
        request_id: builtins.str = ...,
        is_ad: builtins.bool = ...,
        cm_mark: builtins.int = ...,
        index: builtins.int = ...,
        is_ad_loc: builtins.bool = ...,
        card_index: builtins.int = ...,
        client_ip: builtins.str = ...,
        extra: builtins.bytes = ...,
        creative_style: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creative_content", b"creative_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_cb", b"ad_cb", "card_index", b"card_index", "card_type", b"card_type", "client_ip", b"client_ip", "cm_mark", b"cm_mark", "creative_content", b"creative_content", "creative_id", b"creative_id", "creative_style", b"creative_style", "creative_type", b"creative_type", "extra", b"extra", "index", b"index", "is_ad", b"is_ad", "is_ad_loc", b"is_ad_loc", "request_id", b"request_id", "resource", b"resource", "source", b"source"]) -> None: ...

global___AdInfo = AdInfo

@typing_extensions.final
class CreativeContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    IMAGE_MD5_FIELD_NUMBER: builtins.int
    LOG_URL_FIELD_NUMBER: builtins.int
    LOG_MD5_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CLICK_URL_FIELD_NUMBER: builtins.int
    SHOW_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    description: builtins.str
    """"""
    video_id: builtins.int
    """"""
    username: builtins.str
    """"""
    image_url: builtins.str
    """"""
    image_md5: builtins.str
    """"""
    log_url: builtins.str
    """"""
    log_md5: builtins.str
    """"""
    url: builtins.str
    """"""
    click_url: builtins.str
    """"""
    show_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        video_id: builtins.int = ...,
        username: builtins.str = ...,
        image_url: builtins.str = ...,
        image_md5: builtins.str = ...,
        log_url: builtins.str = ...,
        log_md5: builtins.str = ...,
        url: builtins.str = ...,
        click_url: builtins.str = ...,
        show_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["click_url", b"click_url", "description", b"description", "image_md5", b"image_md5", "image_url", b"image_url", "log_md5", b"log_md5", "log_url", b"log_url", "show_url", b"show_url", "title", b"title", "url", b"url", "username", b"username", "video_id", b"video_id"]) -> None: ...

global___CreativeContent = CreativeContent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/v1/test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/test.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"!\n\tAddParams\x12\t\n\x01\x61\x18\x01 \x01(\x05\x12\t\n\x01\x62\x18\x02 \x01(\x05\"\x16\n\tAddResult\x12\t\n\x01r\x18\x01 \x01(\x05\"c\n\x08TestResp\x12\x0e\n\x06taskid\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\x12#\n\x05\x65xtra\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any2S\n\x04Test\x12K\n\x0eWatchTestEvent\x12\x16.google.protobuf.Empty\x1a\x1f.bilibili.broadcast.v1.TestResp0\x01\x32I\n\x05Test2\x12@\n\x04Test\x12 .bilibili.broadcast.v1.AddParams\x1a\x16.google.protobuf.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.v1.test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDPARAMS']._serialized_start=115
  _globals['_ADDPARAMS']._serialized_end=148
  _globals['_ADDRESULT']._serialized_start=150
  _globals['_ADDRESULT']._serialized_end=172
  _globals['_TESTRESP']._serialized_start=174
  _globals['_TESTRESP']._serialized_end=273
  _globals['_TEST']._serialized_start=275
  _globals['_TEST']._serialized_end=358
  _globals['_TEST2']._serialized_start=360
  _globals['_TEST2']._serialized_end=433
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _EncryptType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EncryptTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EncryptType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_ENCRYPT_TYPE: _EncryptType.ValueType  # 0
    """非法值"""
    CLIENT_AES: _EncryptType.ValueType  # 1
    """同客户端人工约定AES加密私钥，存储在客户端"""
    SERVER_RSA_AES: _EncryptType.ValueType  # 2
    """客户端随机生成一个用于AES加密的私钥，并用服务端下发的RSA公钥来加密"""

class EncryptType(_EncryptType, metaclass=_EncryptTypeEnumTypeWrapper):
    """加密方式"""

INVALID_ENCRYPT_TYPE: EncryptType.ValueType  # 0
"""非法值"""
CLIENT_AES: EncryptType.ValueType  # 1
"""同客户端人工约定AES加密私钥，存储在客户端"""
SERVER_RSA_AES: EncryptType.ValueType  # 2
"""客户端随机生成一个用于AES加密的私钥，并用服务端下发的RSA公钥来加密"""
global___EncryptType = EncryptType

class _PayloadType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PayloadTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PayloadType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_PAYLOAD: _PayloadType.ValueType  # 0
    """非法值"""
    DEVICE_APP_LIST: _PayloadType.ValueType  # 1
    """设备app列表，对应DeviceAppList"""

class PayloadType(_PayloadType, metaclass=_PayloadTypeEnumTypeWrapper):
    """负载类型"""

INVALID_PAYLOAD: PayloadType.ValueType  # 0
"""非法值"""
DEVICE_APP_LIST: PayloadType.ValueType  # 1
"""设备app列表，对应DeviceAppList"""
global___PayloadType = PayloadType

@typing_extensions.final
class DeviceAppList(google.protobuf.message.Message):
    """待加密的pb对象"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    SYSTEM_APP_LIST_FIELD_NUMBER: builtins.int
    USER_APP_LIST_FIELD_NUMBER: builtins.int
    source: builtins.str
    """上报类型
    first_installation:首次安装上报 first_open:每日启动上报
    """
    @property
    def system_app_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """安装的系统程序列表"""
    @property
    def user_app_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """安装的用户程序列表"""
    def __init__(
        self,
        *,
        source: builtins.str = ...,
        system_app_list: collections.abc.Iterable[builtins.str] | None = ...,
        user_app_list: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source", b"source", "system_app_list", b"system_app_list", "user_app_list", b"user_app_list"]) -> None: ...

global___DeviceAppList = DeviceAppList

@typing_extensions.final
class FetchPublicKeyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    DEADLINE_FIELD_NUMBER: builtins.int
    version: builtins.str
    """版本号"""
    public_key: builtins.str
    """RSA公钥"""
    deadline: builtins.int
    """公钥过期时间"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        public_key: builtins.str = ...,
        deadline: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deadline", b"deadline", "public_key", b"public_key", "version", b"version"]) -> None: ...

global___FetchPublicKeyReply = FetchPublicKeyReply

@typing_extensions.final
class GaiaDeviceBasicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    SDKVER_FIELD_NUMBER: builtins.int
    APP_VERSION_FIELD_NUMBER: builtins.int
    APP_VERSION_CODE_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BRAND_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    OSVER_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    BUVID_LOCAL_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    FTS_FIELD_NUMBER: builtins.int
    FIRST_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    platform: builtins.str
    """平台&应用信息
    android/ios/web/h5;
    """
    device: builtins.str
    """运行设备, 用于区分不同的app, 见客户端传入的对应参数。对于苹果系统，device有效值为phone, pad；安卓无法区分phone和pad，留空即可。"""
    mobi_app: builtins.str
    """包类型，用于区分不同的app, 见客户端传入的对应参数（mobi_app ）；对于web端请求，请传空"""
    origin: builtins.str
    """客户端appkey, 用以区分不同的客户端，对应客户端请求参数中的appkey,如果无法获取可传空“”"""
    app_id: builtins.str
    """app产品编号 //产品编号，由数据平台分配，粉=1，白=2，蓝=3，直播姬=4，HD=5，海外=6，OTT=7，漫画=8，TV野版=9，小视频=10，网易漫画=11，网易漫画lite=12，网易漫画HD=13,国际版=14"""
    sdkver: builtins.str
    """应用的版本信息
    SDK版本号   "sdkver": "2.6.6"
    """
    app_version: builtins.str
    """app版本  "app_version":"5.36.0" """
    app_version_code: builtins.str
    """app版本号 "app_version_code":"5360000" """
    build: builtins.str
    """app版本号，见客户端传入的对应参数；对于web端请求，请传空"""
    channel: builtins.str
    """渠道信息
    渠道标识，见客户端传入的对应参数；对于web端请求，请传空；对应chid
    """
    brand: builtins.str
    """机器硬件信息
    手机品牌，见客户端传入的对应参数；
    """
    model: builtins.str
    """手机型号，见客户端传入的对应参数"""
    osver: builtins.str
    """系统版本，见客户端传入的对应参数"""
    user_agent: builtins.str
    buvid_local: builtins.str
    """设备标识信息
    本地设备唯一标识
    """
    buvid: builtins.str
    """设备唯一标识"""
    mid: builtins.str
    """登陆用户信息
    最后一次登陆用户的mid，如果无登陆信息，传0即可
    """
    fts: builtins.int
    """本次启动信息
    app首次启动时间 "fts":1530447775661
    """
    first: builtins.int
    """是否首次启动 是：0 否：1"""
    network: builtins.str
    """网络相关的信息
    网络连接方式, WIFI/CELLULAR/OFFLINE/OTHERNET/ETHERNET "network":"WIFI", ESS_NETWORK_STATE、ACCESS_WIFI_STATE
    """
    def __init__(
        self,
        *,
        platform: builtins.str = ...,
        device: builtins.str = ...,
        mobi_app: builtins.str = ...,
        origin: builtins.str = ...,
        app_id: builtins.str = ...,
        sdkver: builtins.str = ...,
        app_version: builtins.str = ...,
        app_version_code: builtins.str = ...,
        build: builtins.str = ...,
        channel: builtins.str = ...,
        brand: builtins.str = ...,
        model: builtins.str = ...,
        osver: builtins.str = ...,
        user_agent: builtins.str = ...,
        buvid_local: builtins.str = ...,
        buvid: builtins.str = ...,
        mid: builtins.str = ...,
        fts: builtins.int = ...,
        first: builtins.int = ...,
        network: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "app_version", b"app_version", "app_version_code", b"app_version_code", "brand", b"brand", "build", b"build", "buvid", b"buvid", "buvid_local", b"buvid_local", "channel", b"channel", "device", b"device", "first", b"first", "fts", b"fts", "mid", b"mid", "mobi_app", b"mobi_app", "model", b"model", "network", b"network", "origin", b"origin", "osver", b"osver", "platform", b"platform", "sdkver", b"sdkver", "user_agent", b"user_agent"]) -> None: ...

global___GaiaDeviceBasicInfo = GaiaDeviceBasicInfo

@typing_extensions.final
class GaiaEncryptMsgReq(google.protobuf.message.Message):
    """应用列表上报-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    ENCRYPT_PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> global___GaiaMsgHeader:
        """上报头部"""
    encrypt_payload: builtins.bytes
    """加密数据"""
    def __init__(
        self,
        *,
        header: global___GaiaMsgHeader | None = ...,
        encrypt_payload: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header", b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encrypt_payload", b"encrypt_payload", "header", b"header"]) -> None: ...

global___GaiaEncryptMsgReq = GaiaEncryptMsgReq

@typing_extensions.final
class GaiaMsgHeader(google.protobuf.message.Message):
    """风控通用消息头"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODE_TYPE_FIELD_NUMBER: builtins.int
    PAYLOAD_TYPE_FIELD_NUMBER: builtins.int
    ENCODED_AES_KEY_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    encode_type: global___EncryptType.ValueType
    """加密类型"""
    payload_type: global___PayloadType.ValueType
    """类型"""
    encoded_aes_key: builtins.bytes
    """RAS加密后的aes_key"""
    ts: builtins.int
    """当前时间戳(ms)"""
    def __init__(
        self,
        *,
        encode_type: global___EncryptType.ValueType = ...,
        payload_type: global___PayloadType.ValueType = ...,
        encoded_aes_key: builtins.bytes = ...,
        ts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encode_type", b"encode_type", "encoded_aes_key", b"encoded_aes_key", "payload_type", b"payload_type", "ts", b"ts"]) -> None: ...

global___GaiaMsgHeader = GaiaMsgHeader

@typing_extensions.final
class UploadAppListReply(google.protobuf.message.Message):
    """应用列表上报-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRACE_ID_FIELD_NUMBER: builtins.int
    trace_id: builtins.str
    """上报响应id"""
    def __init__(
        self,
        *,
        trace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["trace_id", b"trace_id"]) -> None: ...

global___UploadAppListReply = UploadAppListReply



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Device(google.protobuf.message.Message):
    """设备信息
    gRPC头部:x-bili-device-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BRAND_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    OSVER_FIELD_NUMBER: builtins.int
    FP_LOCAL_FIELD_NUMBER: builtins.int
    FP_REMOTE_FIELD_NUMBER: builtins.int
    VERSION_NAME_FIELD_NUMBER: builtins.int
    FP_FIELD_NUMBER: builtins.int
    FTS_FIELD_NUMBER: builtins.int
    app_id: builtins.int
    """产品id
    粉 白 蓝 直播姬 HD 海外 OTT 漫画 TV野版 小视频 网易漫画 网易漫画 网易漫画HD 国际版 东南亚版
    1  2  3    4    5   6    7   8     9     10      11       12       13       14       30
    """
    build: builtins.int
    """构建id"""
    buvid: builtins.str
    """设备buvid"""
    mobi_app: builtins.str
    """包类型"""
    platform: builtins.str
    """平台类型
    ios android
    """
    device: builtins.str
    """设备类型"""
    channel: builtins.str
    """渠道"""
    brand: builtins.str
    """手机品牌"""
    model: builtins.str
    """手机型号"""
    osver: builtins.str
    """系统版本"""
    fp_local: builtins.str
    """本地设备指纹"""
    fp_remote: builtins.str
    """远程设备指纹"""
    version_name: builtins.str
    """APP版本号"""
    fp: builtins.str
    """设备指纹, 不区分本地或远程设备指纹，作为推送目标的索引"""
    fts: builtins.int
    """首次启动时的毫秒时间戳"""
    def __init__(
        self,
        *,
        app_id: builtins.int = ...,
        build: builtins.int = ...,
        buvid: builtins.str = ...,
        mobi_app: builtins.str = ...,
        platform: builtins.str = ...,
        device: builtins.str = ...,
        channel: builtins.str = ...,
        brand: builtins.str = ...,
        model: builtins.str = ...,
        osver: builtins.str = ...,
        fp_local: builtins.str = ...,
        fp_remote: builtins.str = ...,
        version_name: builtins.str = ...,
        fp: builtins.str = ...,
        fts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "brand", b"brand", "build", b"build", "buvid", b"buvid", "channel", b"channel", "device", b"device", "fp", b"fp", "fp_local", b"fp_local", "fp_remote", b"fp_remote", "fts", b"fts", "mobi_app", b"mobi_app", "model", b"model", "osver", b"osver", "platform", b"platform", "version_name", b"version_name"]) -> None: ...

global___Device = Device



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datacenter/hakase/protobuf/android_device_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4datacenter/hakase/protobuf/android_device_info.proto\x12\x1a\x64\x61tacenter.hakase.protobuf\"\xa6\x13\n\x11\x41ndroidDeviceInfo\x12\x0e\n\x06sdkver\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\t\x12\x18\n\x10\x61pp_version_code\x18\x04 \x01(\t\x12\x0b\n\x03mid\x18\x05 \x01(\t\x12\x0c\n\x04\x63hid\x18\x06 \x01(\t\x12\x0b\n\x03\x66ts\x18\x07 \x01(\x03\x12\x13\n\x0b\x62uvid_local\x18\x08 \x01(\t\x12\r\n\x05\x66irst\x18\t \x01(\x05\x12\x0c\n\x04proc\x18\n \x01(\t\x12\x0b\n\x03net\x18\x0b \x01(\t\x12\x0c\n\x04\x62\x61nd\x18\x0c \x01(\t\x12\r\n\x05osver\x18\r \x01(\t\x12\t\n\x01t\x18\x0e \x01(\x03\x12\x11\n\tcpu_count\x18\x0f \x01(\x05\x12\r\n\x05model\x18\x10 \x01(\t\x12\r\n\x05\x62rand\x18\x11 \x01(\t\x12\x0e\n\x06screen\x18\x12 \x01(\t\x12\x11\n\tcpu_model\x18\x13 \x01(\t\x12\r\n\x05\x62tmac\x18\x14 \x01(\t\x12\x0c\n\x04\x62oot\x18\x15 \x01(\x03\x12\x0b\n\x03\x65mu\x18\x16 \x01(\t\x12\x0b\n\x03oid\x18\x17 \x01(\t\x12\x0f\n\x07network\x18\x18 \x01(\t\x12\x0b\n\x03mem\x18\x19 \x01(\x03\x12\x0e\n\x06sensor\x18\x1a \x01(\t\x12\x10\n\x08\x63pu_freq\x18\x1b \x01(\x03\x12\x12\n\ncpu_vendor\x18\x1c \x01(\t\x12\x0b\n\x03sim\x18\x1d \x01(\t\x12\x12\n\nbrightness\x18\x1e \x01(\x05\x12G\n\x05props\x18\x1f \x03(\x0b\x32\x38.datacenter.hakase.protobuf.AndroidDeviceInfo.PropsEntry\x12\x43\n\x03sys\x18  \x03(\x0b\x32\x36.datacenter.hakase.protobuf.AndroidDeviceInfo.SysEntry\x12\x0f\n\x07wifimac\x18! \x01(\t\x12\x0c\n\x04\x61\x64id\x18\" \x01(\t\x12\n\n\x02os\x18# \x01(\t\x12\x0c\n\x04imei\x18$ \x01(\t\x12\x0c\n\x04\x63\x65ll\x18% \x01(\t\x12\x0c\n\x04imsi\x18& \x01(\t\x12\r\n\x05iccid\x18\' \x01(\t\x12\x0e\n\x06\x63\x61mcnt\x18( \x01(\x05\x12\r\n\x05\x63\x61mpx\x18) \x01(\t\x12\x13\n\x0btotal_space\x18* \x01(\x03\x12\x0f\n\x07\x61xposed\x18+ \x01(\t\x12\x0c\n\x04maps\x18, \x01(\t\x12\r\n\x05\x66iles\x18- \x01(\t\x12\x0f\n\x07virtual\x18. \x01(\t\x12\x13\n\x0bvirtualproc\x18/ \x01(\t\x12\r\n\x05gadid\x18\x30 \x01(\t\x12\x0e\n\x06glimit\x18\x31 \x01(\t\x12\x0c\n\x04\x61pps\x18\x32 \x01(\t\x12\x0c\n\x04guid\x18\x33 \x01(\t\x12\x0b\n\x03uid\x18\x34 \x01(\t\x12\x0c\n\x04root\x18\x35 \x01(\x05\x12\x0f\n\x07\x63\x61mzoom\x18\x36 \x01(\t\x12\x10\n\x08\x63\x61mlight\x18\x37 \x01(\t\x12\x0c\n\x04oaid\x18\x38 \x01(\t\x12\x0c\n\x04udid\x18\x39 \x01(\t\x12\x0c\n\x04vaid\x18: \x01(\t\x12\x0c\n\x04\x61\x61id\x18; \x01(\t\x12\x14\n\x0c\x61ndroidapp20\x18< \x01(\t\x12\x15\n\randroidappcnt\x18= \x01(\x05\x12\x17\n\x0f\x61ndroidsysapp20\x18> \x01(\t\x12\x0f\n\x07\x62\x61ttery\x18? \x01(\x05\x12\x15\n\rbattery_state\x18@ \x01(\t\x12\r\n\x05\x62ssid\x18\x41 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x43 \x01(\t\x12\x13\n\x0b\x63ountry_iso\x18\x44 \x01(\t\x12\x13\n\x0b\x66ree_memory\x18\x46 \x01(\x03\x12\x10\n\x08\x66storage\x18G \x01(\t\x12\x16\n\x0ekernel_version\x18J \x01(\t\x12\x11\n\tlanguages\x18K \x01(\t\x12\x0b\n\x03mac\x18L \x01(\t\x12\x0c\n\x04ssid\x18O \x01(\t\x12\x14\n\x0csystemvolume\x18P \x01(\x05\x12\x13\n\x0bwifimaclist\x18Q \x01(\t\x12\x0e\n\x06memory\x18R \x01(\x03\x12\x13\n\x0bstr_battery\x18S \x01(\t\x12\x0f\n\x07is_root\x18T \x01(\x08\x12\x16\n\x0estr_brightness\x18U \x01(\t\x12\x12\n\nstr_app_id\x18V \x01(\t\x12\n\n\x02ip\x18W \x01(\t\x12\x12\n\nuser_agent\x18X \x01(\t\x12\x17\n\x0flight_intensity\x18Y \x01(\t\x12\x14\n\x0c\x64\x65vice_angle\x18Z \x03(\x02\x12\x12\n\ngps_sensor\x18[ \x01(\x03\x12\x14\n\x0cspeed_sensor\x18\\ \x01(\x03\x12\x1b\n\x13linear_speed_sensor\x18] \x01(\x03\x12\x18\n\x10gyroscope_sensor\x18^ \x01(\x03\x12\x11\n\tbiometric\x18_ \x01(\x03\x12\x12\n\nbiometrics\x18` \x03(\t\x12\x14\n\x0clast_dump_ts\x18\x61 \x01(\x03\x12\x10\n\x08location\x18\x62 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x63 \x01(\t\x12\x0c\n\x04\x63ity\x18\x64 \x01(\t\x12\x1b\n\x13\x64\x61ta_activity_state\x18\x65 \x01(\x05\x12\x1a\n\x12\x64\x61ta_connect_state\x18\x66 \x01(\x05\x12\x19\n\x11\x64\x61ta_network_type\x18g \x01(\x05\x12\x1a\n\x12voice_network_type\x18h \x01(\x05\x12\x1b\n\x13voice_service_state\x18i \x01(\x05\x12\x15\n\rusb_connected\x18j \x01(\x05\x12\x13\n\x0b\x61\x64\x62_enabled\x18k \x01(\x05\x12\x12\n\nui_version\x18l \x01(\t\x12\x1d\n\x15\x61\x63\x63\x65ssibility_service\x18m \x03(\t\x12<\n\x0csensors_info\x18n \x03(\x0b\x32&.datacenter.hakase.protobuf.SensorInfo\x12\r\n\x05\x64rmid\x18o \x01(\t\x12\x17\n\x0f\x62\x61ttery_present\x18p \x01(\x08\x12\x1a\n\x12\x62\x61ttery_technology\x18q \x01(\t\x12\x1b\n\x13\x62\x61ttery_temperature\x18r \x01(\x05\x12\x17\n\x0f\x62\x61ttery_voltage\x18s \x01(\x05\x12\x17\n\x0f\x62\x61ttery_plugged\x18t \x01(\x05\x12\x16\n\x0e\x62\x61ttery_health\x18u \x01(\x05\x12\x14\n\x0c\x63pu_abi_list\x18v \x03(\t\x12\x14\n\x0c\x63pu_abi_libc\x18w \x01(\t\x12\x16\n\x0e\x63pu_abi_libc64\x18x \x01(\t\x12\x15\n\rcpu_processor\x18y \x01(\t\x12\x16\n\x0e\x63pu_model_name\x18z \x01(\t\x12\x14\n\x0c\x63pu_hardware\x18{ \x01(\t\x12\x14\n\x0c\x63pu_features\x18| \x01(\t\x1a,\n\nPropsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a*\n\x08SysEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\nSensorInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x11\n\tmax_range\x18\x05 \x01(\x02\x12\x12\n\nresolution\x18\x06 \x01(\x02\x12\r\n\x05power\x18\x07 \x01(\x02\x12\x11\n\tmin_delay\x18\x08 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'datacenter.hakase.protobuf.android_device_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANDROIDDEVICEINFO_PROPSENTRY._options = None
  _ANDROIDDEVICEINFO_PROPSENTRY._serialized_options = b'8\001'
  _ANDROIDDEVICEINFO_SYSENTRY._options = None
  _ANDROIDDEVICEINFO_SYSENTRY._serialized_options = b'8\001'
  _globals['_ANDROIDDEVICEINFO']._serialized_start=85
  _globals['_ANDROIDDEVICEINFO']._serialized_end=2555
  _globals['_ANDROIDDEVICEINFO_PROPSENTRY']._serialized_start=2467
  _globals['_ANDROIDDEVICEINFO_PROPSENTRY']._serialized_end=2511
  _globals['_ANDROIDDEVICEINFO_SYSENTRY']._serialized_start=2513
  _globals['_ANDROIDDEVICEINFO_SYSENTRY']._serialized_end=2555
  _globals['_SENSORINFO']._serialized_start=2558
  _globals['_SENSORINFO']._serialized_end=2704
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/parabox/parabox.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/metadata/parabox/parabox.proto\x12\x19\x62ilibili.metadata.parabox\"!\n\x03\x45xp\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\x05\"4\n\x04\x45xps\x12,\n\x04\x65xps\x18\x01 \x03(\x0b\x32\x1e.bilibili.metadata.parabox.Expb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.parabox.parabox_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EXP']._serialized_start=70
  _globals['_EXP']._serialized_end=103
  _globals['_EXPS']._serialized_start=105
  _globals['_EXPS']._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/playerunite/pgcanymodel/pgcanymodel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.pgc.gateway.player.v2 import playurl_pb2 as bilibili_dot_pgc_dot_gateway_dot_player_dot_v2_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6bilibili/app/playerunite/pgcanymodel/pgcanymodel.proto\x12$bilibili.app.playerunite.pgcanymodel\x1a,bilibili/pgc/gateway/player/v2/playurl.proto\"\xd7\x02\n\x0bPGCAnyModel\x12\x46\n\x08\x62usiness\x18\x03 \x01(\x0b\x32\x34.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo\x12\x34\n\x05\x65vent\x18\x04 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Event\x12;\n\tview_info\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.ViewInfo\x12I\n\rplay_ext_conf\x18\x06 \x01(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.PlayAbilityExtConf\x12\x42\n\rplay_ext_info\x18\x07 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.PlayExtInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.playerunite.pgcanymodel.pgcanymodel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PGCANYMODEL']._serialized_start=143
  _globals['_PGCANYMODEL']._serialized_end=486
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/play.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/app/distribution/setting/play.proto\x12&bilibili.app.distribution.setting.play\x1a/bilibili/app/distribution/v1/distribution.proto\"\xd8\x02\n\x0f\x43loudPlayConfig\x12@\n\x0f\x65nable_panorama\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12=\n\x0c\x65nable_dolby\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12=\n\x0c\x65nable_shake\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x42\n\x11\x65nable_background\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x41\n\x10\x65nable_loss_less\x18\x05 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"\xec\x07\n\nPlayConfig\x12\x41\n\x10should_auto_play\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12G\n\x16should_auto_fullscreen\x18\x02 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x14\x65nable_playurl_https\x18\x03 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12K\n\x1a\x65nable_danmaku_interaction\x18\x04 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x13small_screen_status\x18\x05 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12G\n\x15player_codec_mode_key\x18\x06 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12M\n\x1c\x65nable_gravity_rotate_screen\x18\x07 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12J\n\x19\x65nable_danmaku_monospaced\x18\x08 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x14\x65nable_edit_subtitle\x18\t \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12@\n\x0f\x65nable_subtitle\x18\n \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12>\n\x0c\x63olor_filter\x18\x0b \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x42\n\x11should_auto_story\x18\x0c \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12\x45\n\x14landscape_auto_story\x18\r \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\x12?\n\x0evolume_balance\x18\x0e \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"_\n\x12SpecificPlayConfig\x12I\n\x18\x65nable_segmented_section\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.play_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLOUDPLAYCONFIG']._serialized_start=138
  _globals['_CLOUDPLAYCONFIG']._serialized_end=482
  _globals['_PLAYCONFIG']._serialized_start=485
  _globals['_PLAYCONFIG']._serialized_end=1489
  _globals['_SPECIFICPLAYCONFIG']._serialized_start=1491
  _globals['_SPECIFICPLAYCONFIG']._serialized_end=1586
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Bubble(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAGRAPHS_FIELD_NUMBER: builtins.int
    @property
    def paragraphs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.app.dynamic.v2.dynamic_pb2.Paragraph]: ...
    def __init__(
        self,
        *,
        paragraphs: collections.abc.Iterable[bilibili.app.dynamic.v2.dynamic_pb2.Paragraph] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["paragraphs", b"paragraphs"]) -> None: ...

global___Bubble = Bubble

@typing_extensions.final
class ChatResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    REWRITE_WORD_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    session_id: builtins.str
    """"""
    @property
    def bubble(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Bubble]:
        """"""
    rewrite_word: builtins.str
    """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        session_id: builtins.str = ...,
        bubble: collections.abc.Iterable[global___Bubble] | None = ...,
        rewrite_word: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble", b"bubble", "code", b"code", "rewrite_word", b"rewrite_word", "session_id", b"session_id", "title", b"title"]) -> None: ...

global___ChatResult = ChatResult



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/message/tv/proj.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/broadcast/message/tv/proj.proto\x12\x1d\x62ilibili.broadcast.message.tv\x1a\x1bgoogle/protobuf/empty.proto\"\x9a\x01\n\tProjReply\x12\x10\n\x08\x63md_type\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x12\n\nvideo_type\x18\x05 \x01(\x03\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x11\n\tseason_id\x18\x07 \x01(\x03\x12\x0f\n\x07seek_ts\x18\x08 \x01(\x03\x12\r\n\x05\x65xtra\x18\t \x01(\t\"<\n\x10LiveStatusNotify\x12\x0e\n\x06status\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\x1c\n\rEsportsNotify\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\"H\n\x0fPublicityNotify\x12\x14\n\x0cpublicity_id\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x03\"!\n\x0eLiveSkipNotify\x12\x0f\n\x07live_id\x18\x01 \x01(\x03\x32\xa8\x03\n\x02Tv\x12J\n\x04Proj\x12\x16.google.protobuf.Empty\x1a(.bilibili.broadcast.message.tv.ProjReply0\x01\x12W\n\nLiveStatus\x12\x16.google.protobuf.Empty\x1a/.bilibili.broadcast.message.tv.LiveStatusNotify0\x01\x12Q\n\x07\x45sports\x12\x16.google.protobuf.Empty\x1a,.bilibili.broadcast.message.tv.EsportsNotify0\x01\x12U\n\tPublicity\x12\x16.google.protobuf.Empty\x1a..bilibili.broadcast.message.tv.PublicityNotify0\x01\x12S\n\x08LiveSkip\x12\x16.google.protobuf.Empty\x1a-.bilibili.broadcast.message.tv.LiveSkipNotify0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.tv.proj_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PROJREPLY']._serialized_start=105
  _globals['_PROJREPLY']._serialized_end=259
  _globals['_LIVESTATUSNOTIFY']._serialized_start=261
  _globals['_LIVESTATUSNOTIFY']._serialized_end=321
  _globals['_ESPORTSNOTIFY']._serialized_start=323
  _globals['_ESPORTSNOTIFY']._serialized_end=351
  _globals['_PUBLICITYNOTIFY']._serialized_start=353
  _globals['_PUBLICITYNOTIFY']._serialized_end=425
  _globals['_LIVESKIPNOTIFY']._serialized_start=427
  _globals['_LIVESKIPNOTIFY']._serialized_end=460
  _globals['_TV']._serialized_start=463
  _globals['_TV']._serialized_end=887
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BusinessInfo(google.protobuf.message.Message):
    """其他业务信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_PREVIEW_FIELD_NUMBER: builtins.int
    BP_FIELD_NUMBER: builtins.int
    MARLIN_TOKEN_FIELD_NUMBER: builtins.int
    is_preview: builtins.bool
    """当前视频是否是预览"""
    bp: builtins.bool
    """用户是否承包过"""
    marlin_token: builtins.str
    """drm使用"""
    def __init__(
        self,
        *,
        is_preview: builtins.bool = ...,
        bp: builtins.bool = ...,
        marlin_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bp", b"bp", "is_preview", b"is_preview", "marlin_token", b"marlin_token"]) -> None: ...

global___BusinessInfo = BusinessInfo

@typing_extensions.final
class Event(google.protobuf.message.Message):
    """事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
    def __init__(
        self,
        *,
        shake: global___Shake | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> None: ...

global___Event = Event

@typing_extensions.final
class LivePlayInfo(google.protobuf.message.Message):
    """播放信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_QN_FIELD_NUMBER: builtins.int
    QUALITY_DESCRIPTION_FIELD_NUMBER: builtins.int
    DURL_FIELD_NUMBER: builtins.int
    current_qn: builtins.int
    """"""
    @property
    def quality_description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QualityDescription]:
        """"""
    @property
    def durl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseDataUrl]:
        """"""
    def __init__(
        self,
        *,
        current_qn: builtins.int = ...,
        quality_description: collections.abc.Iterable[global___QualityDescription] | None = ...,
        durl: collections.abc.Iterable[global___ResponseDataUrl] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_qn", b"current_qn", "durl", b"durl", "quality_description", b"quality_description"]) -> None: ...

global___LivePlayInfo = LivePlayInfo

@typing_extensions.final
class LivePlayViewReply(google.protobuf.message.Message):
    """直播播放页信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_INFO_FIELD_NUMBER: builtins.int
    PLAY_INFO_FIELD_NUMBER: builtins.int
    @property
    def room_info(self) -> global___RoomInfo:
        """房间信息"""
    @property
    def play_info(self) -> global___LivePlayInfo:
        """播放信息"""
    def __init__(
        self,
        *,
        room_info: global___RoomInfo | None = ...,
        play_info: global___LivePlayInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_info", b"play_info", "room_info", b"room_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_info", b"play_info", "room_info", b"room_info"]) -> None: ...

global___LivePlayViewReply = LivePlayViewReply

@typing_extensions.final
class LivePlayViewReq(google.protobuf.message.Message):
    """直播播放页信息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EP_ID_FIELD_NUMBER: builtins.int
    QUALITY_FIELD_NUMBER: builtins.int
    PTYPE_FIELD_NUMBER: builtins.int
    HTTPS_FIELD_NUMBER: builtins.int
    PLAY_TYPE_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """剧集epid"""
    quality: builtins.int
    """清晰度
    0,10000:原画 400:蓝光 250:超清 150:高清 80:流畅
    """
    ptype: builtins.int
    """类型
    0:音频 2:hevc 4:dash 8:p2p, 16:蒙版
    """
    https: builtins.bool
    """是否请求https"""
    play_type: builtins.int
    """0:默认直播间播放 1:投屏播放"""
    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """
    def __init__(
        self,
        *,
        ep_id: builtins.int = ...,
        quality: builtins.int = ...,
        ptype: builtins.int = ...,
        https: builtins.bool = ...,
        play_type: builtins.int = ...,
        device_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_type", b"device_type", "ep_id", b"ep_id", "https", b"https", "play_type", b"play_type", "ptype", b"ptype", "quality", b"quality"]) -> None: ...

global___LivePlayViewReq = LivePlayViewReq

@typing_extensions.final
class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_PLAY_DISABLE_FIELD_NUMBER: builtins.int
    FLIP_DISABLE_FIELD_NUMBER: builtins.int
    CAST_DISABLE_FIELD_NUMBER: builtins.int
    FEEDBACK_DISABLE_FIELD_NUMBER: builtins.int
    SUBTITLE_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_DISABLE_FIELD_NUMBER: builtins.int
    TIME_UP_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_DISABLE_FIELD_NUMBER: builtins.int
    SCALE_MODE_DISABLE_FIELD_NUMBER: builtins.int
    LIKE_DISABLE_FIELD_NUMBER: builtins.int
    DISLIKE_DISABLE_FIELD_NUMBER: builtins.int
    COIN_DISABLE_FIELD_NUMBER: builtins.int
    ELEC_DISABLE_FIELD_NUMBER: builtins.int
    SHARE_DISABLE_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_DISABLE_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    RECOMMEND_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_DISABLE_FIELD_NUMBER: builtins.int
    DEFINITION_DISABLE_FIELD_NUMBER: builtins.int
    SELECTIONS_DISABLE_FIELD_NUMBER: builtins.int
    NEXT_DISABLE_FIELD_NUMBER: builtins.int
    EDIT_DM_DISABLE_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_DISABLE_FIELD_NUMBER: builtins.int
    SHAKE_DISABLE_FIELD_NUMBER: builtins.int
    OUTER_DM_DISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_ENTER_DISABLE_FIELD_NUMBER: builtins.int
    DOLBY_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_FULL_DISABLE_FIELD_NUMBER: builtins.int
    SKIP_OPED_SWITCH_DISABLE_FIELD_NUMBER: builtins.int
    background_play_disable: builtins.bool
    """后台播放"""
    flip_disable: builtins.bool
    """镜像反转"""
    cast_disable: builtins.bool
    """投屏"""
    feedback_disable: builtins.bool
    """反馈"""
    subtitle_disable: builtins.bool
    """字幕"""
    playback_rate_disable: builtins.bool
    """播放速度"""
    time_up_disable: builtins.bool
    """定时停止"""
    playback_mode_disable: builtins.bool
    """播放方式"""
    scale_mode_disable: builtins.bool
    """画面尺寸"""
    like_disable: builtins.bool
    """赞"""
    dislike_disable: builtins.bool
    """踩"""
    coin_disable: builtins.bool
    """投币"""
    elec_disable: builtins.bool
    """充电"""
    share_disable: builtins.bool
    """分享"""
    screen_shot_disable: builtins.bool
    """截图"""
    lock_screen_disable: builtins.bool
    """锁定"""
    recommend_disable: builtins.bool
    """相关推荐"""
    playback_speed_disable: builtins.bool
    """播放速度"""
    definition_disable: builtins.bool
    """清晰度"""
    selections_disable: builtins.bool
    """选集"""
    next_disable: builtins.bool
    """下一集"""
    edit_dm_disable: builtins.bool
    """编辑弹幕"""
    small_window_disable: builtins.bool
    """小窗"""
    shake_disable: builtins.bool
    """震动"""
    outer_dm_disable: builtins.bool
    """外层面板弹幕设置"""
    inner_dm_disable: builtins.bool
    """三点内弹幕设置"""
    freya_enter_disable: builtins.bool
    """一起看入口"""
    dolby_disable: builtins.bool
    """杜比音效"""
    freya_full_disable: builtins.bool
    """全屏一起看入口"""
    skip_oped_switch_disable: builtins.bool
    """"""
    def __init__(
        self,
        *,
        background_play_disable: builtins.bool = ...,
        flip_disable: builtins.bool = ...,
        cast_disable: builtins.bool = ...,
        feedback_disable: builtins.bool = ...,
        subtitle_disable: builtins.bool = ...,
        playback_rate_disable: builtins.bool = ...,
        time_up_disable: builtins.bool = ...,
        playback_mode_disable: builtins.bool = ...,
        scale_mode_disable: builtins.bool = ...,
        like_disable: builtins.bool = ...,
        dislike_disable: builtins.bool = ...,
        coin_disable: builtins.bool = ...,
        elec_disable: builtins.bool = ...,
        share_disable: builtins.bool = ...,
        screen_shot_disable: builtins.bool = ...,
        lock_screen_disable: builtins.bool = ...,
        recommend_disable: builtins.bool = ...,
        playback_speed_disable: builtins.bool = ...,
        definition_disable: builtins.bool = ...,
        selections_disable: builtins.bool = ...,
        next_disable: builtins.bool = ...,
        edit_dm_disable: builtins.bool = ...,
        small_window_disable: builtins.bool = ...,
        shake_disable: builtins.bool = ...,
        outer_dm_disable: builtins.bool = ...,
        inner_dm_disable: builtins.bool = ...,
        freya_enter_disable: builtins.bool = ...,
        dolby_disable: builtins.bool = ...,
        freya_full_disable: builtins.bool = ...,
        skip_oped_switch_disable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_disable", b"background_play_disable", "cast_disable", b"cast_disable", "coin_disable", b"coin_disable", "definition_disable", b"definition_disable", "dislike_disable", b"dislike_disable", "dolby_disable", b"dolby_disable", "edit_dm_disable", b"edit_dm_disable", "elec_disable", b"elec_disable", "feedback_disable", b"feedback_disable", "flip_disable", b"flip_disable", "freya_enter_disable", b"freya_enter_disable", "freya_full_disable", b"freya_full_disable", "inner_dm_disable", b"inner_dm_disable", "like_disable", b"like_disable", "lock_screen_disable", b"lock_screen_disable", "next_disable", b"next_disable", "outer_dm_disable", b"outer_dm_disable", "playback_mode_disable", b"playback_mode_disable", "playback_rate_disable", b"playback_rate_disable", "playback_speed_disable", b"playback_speed_disable", "recommend_disable", b"recommend_disable", "scale_mode_disable", b"scale_mode_disable", "screen_shot_disable", b"screen_shot_disable", "selections_disable", b"selections_disable", "shake_disable", b"shake_disable", "share_disable", b"share_disable", "skip_oped_switch_disable", b"skip_oped_switch_disable", "small_window_disable", b"small_window_disable", "subtitle_disable", b"subtitle_disable", "time_up_disable", b"time_up_disable"]) -> None: ...

global___PlayAbilityConf = PlayAbilityConf

@typing_extensions.final
class PlayViewReply(google.protobuf.message.Message):
    """ 播放页信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.VideoInfo:
        """视频流信息"""
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
    @property
    def business(self) -> global___BusinessInfo:
        """业务需要的其他信息"""
    @property
    def event(self) -> global___Event:
        """事件"""
    def __init__(
        self,
        *,
        video_info: bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.VideoInfo | None = ...,
        play_conf: global___PlayAbilityConf | None = ...,
        business: global___BusinessInfo | None = ...,
        event: global___Event | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_conf", b"play_conf", "video_info", b"video_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_conf", b"play_conf", "video_info", b"video_info"]) -> None: ...

global___PlayViewReply = PlayViewReply

@typing_extensions.final
class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    epid: builtins.int
    """剧集epid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    teenagers_mode: builtins.int
    """青少年模式"""
    prefer_codec_type: bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType
    """视频编码"""
    is_preview: builtins.bool
    """是否强制请求预览视频"""
    room_id: builtins.int
    """一起看房间id"""
    def __init__(
        self,
        *,
        epid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType = ...,
        is_preview: builtins.bool = ...,
        room_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "download", b"download", "epid", b"epid", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "is_preview", b"is_preview", "prefer_codec_type", b"prefer_codec_type", "qn", b"qn", "room_id", b"room_id", "spmid", b"spmid", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___PlayViewReq = PlayViewReq

@typing_extensions.final
class ProjectReply(google.protobuf.message.Message):
    """投屏地址-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.PlayURLReply: ...
    def __init__(
        self,
        *,
        project: bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.PlayURLReply | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project", b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project"]) -> None: ...

global___ProjectReply = ProjectReply

@typing_extensions.final
class ProjectReq(google.protobuf.message.Message):
    """投屏地址-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCEHOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROMSPMID_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    USE_NEW_PROJECT_CODE_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """剧集epid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    forceHost: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    fromSpmid: builtins.str
    """上一页spm"""
    protocol: builtins.int
    """使用协议
    0:默认乐播 1:自建协议 2:云投屏 3:airplay
    """
    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """
    use_new_project_code: builtins.bool
    """"""
    def __init__(
        self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        forceHost: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        fromSpmid: builtins.str = ...,
        protocol: builtins.int = ...,
        device_type: builtins.int = ...,
        use_new_project_code: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "device_type", b"device_type", "download", b"download", "ep_id", b"ep_id", "fnval", b"fnval", "fnver", b"fnver", "forceHost", b"forceHost", "fourk", b"fourk", "fromSpmid", b"fromSpmid", "protocol", b"protocol", "qn", b"qn", "spmid", b"spmid", "use_new_project_code", b"use_new_project_code"]) -> None: ...

global___ProjectReq = ProjectReq

@typing_extensions.final
class QualityDescription(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "qn", b"qn"]) -> None: ...

global___QualityDescription = QualityDescription

@typing_extensions.final
class ResponseDataUrl(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    STREAM_TYPE_FIELD_NUMBER: builtins.int
    PTAG_FIELD_NUMBER: builtins.int
    url: builtins.str
    stream_type: builtins.int
    """表示stream类型,按位表示
    Value|  1   |  1  |  1   |  1   |     1
    --------------------------------------------
    desc | mask | p2p | dash | hevc | only-audio
    """
    ptag: builtins.int
    """表示支持p2p的cdn厂商,按位表示
    值   | 1  |  1  |  1  | 1  |  1  | 1  | 1  | 1
    -----------------------------------------------
    CDN	| hw | bdy | bsy | ws | txy | qn | js | bvc
    """
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        stream_type: builtins.int = ...,
        ptag: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ptag", b"ptag", "stream_type", b"stream_type", "url", b"url"]) -> None: ...

global___ResponseDataUrl = ResponseDataUrl

@typing_extensions.final
class RoomInfo(google.protobuf.message.Message):
    """房间信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间长号"""
    uid: builtins.int
    """主播mid"""
    @property
    def status(self) -> global___RoomStatusInfo:
        """状态相关"""
    @property
    def show(self) -> global___RoomShowInfo:
        """展示相关"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
        uid: builtins.int = ...,
        status: global___RoomStatusInfo | None = ...,
        show: global___RoomShowInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["show", b"show", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id", b"room_id", "show", b"show", "status", b"status", "uid", b"uid"]) -> None: ...

global___RoomInfo = RoomInfo

@typing_extensions.final
class RoomShowInfo(google.protobuf.message.Message):
    """房间信息-展示相关"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHORT_ID_FIELD_NUMBER: builtins.int
    POPULARITY_COUNT_FIELD_NUMBER: builtins.int
    LIVE_START_TIME_FIELD_NUMBER: builtins.int
    short_id: builtins.int
    """短号"""
    popularity_count: builtins.int
    """人气值"""
    live_start_time: builtins.int
    """最近一次开播时间戳"""
    def __init__(
        self,
        *,
        short_id: builtins.int = ...,
        popularity_count: builtins.int = ...,
        live_start_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["live_start_time", b"live_start_time", "popularity_count", b"popularity_count", "short_id", b"short_id"]) -> None: ...

global___RoomShowInfo = RoomShowInfo

@typing_extensions.final
class RoomStatusInfo(google.protobuf.message.Message):
    """房间信息-状态相关"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_STATUS_FIELD_NUMBER: builtins.int
    LIVE_SCREEN_TYPE_FIELD_NUMBER: builtins.int
    LIVE_MARK_FIELD_NUMBER: builtins.int
    LOCK_STATUS_FIELD_NUMBER: builtins.int
    LOCK_TIME_FIELD_NUMBER: builtins.int
    HIDDEN_STATUS_FIELD_NUMBER: builtins.int
    HIDDEN_TIME_FIELD_NUMBER: builtins.int
    LIVE_TYPE_FIELD_NUMBER: builtins.int
    ROOM_SHIELD_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """直播间状态
    0:未开播 1:直播中 2:轮播中
    """
    live_screen_type: builtins.int
    """横竖屏方向
    0:横屏 1:竖屏
    """
    live_mark: builtins.int
    """是否开播过标识"""
    lock_status: builtins.int
    """封禁状态
    0:未封禁 1:审核封禁 2:全网封禁
    """
    lock_time: builtins.int
    """封禁时间戳"""
    hidden_status: builtins.int
    """隐藏状态
    0:不隐藏 1:隐藏
    """
    hidden_time: builtins.int
    """隐藏时间戳"""
    live_type: builtins.int
    """直播类型
    0:默认 1:摄像头直播 2;录屏直播 3:语音直播
    """
    room_shield: builtins.int
    """"""
    def __init__(
        self,
        *,
        live_status: builtins.int = ...,
        live_screen_type: builtins.int = ...,
        live_mark: builtins.int = ...,
        lock_status: builtins.int = ...,
        lock_time: builtins.int = ...,
        hidden_status: builtins.int = ...,
        hidden_time: builtins.int = ...,
        live_type: builtins.int = ...,
        room_shield: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hidden_status", b"hidden_status", "hidden_time", b"hidden_time", "live_mark", b"live_mark", "live_screen_type", b"live_screen_type", "live_status", b"live_status", "live_type", b"live_type", "lock_status", b"lock_status", "lock_time", b"lock_time", "room_shield", b"room_shield"]) -> None: ...

global___RoomStatusInfo = RoomStatusInfo

@typing_extensions.final
class Shake(google.protobuf.message.Message):
    """震动"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    """文件地址"""
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___Shake = Shake



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/list/v1/list.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/polymer/list/v1/list.proto\x12\x18\x62ilibili.polymer.list.v1\"#\n\x11\x43heckAccountReply\x12\x0e\n\x06is_new\x18\x01 \x01(\x08\"/\n\x0f\x43heckAccountReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0f\n\x07periods\x18\x02 \x01(\t\":\n\x0f\x46\x61voriteTabItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"L\n\x10\x46\x61voriteTabReply\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32).bilibili.polymer.list.v1.FavoriteTabItem\"\x10\n\x0e\x46\x61voriteTabReq2\xd3\x01\n\x04List\x12\x63\n\x0b\x46\x61voriteTab\x12(.bilibili.polymer.list.v1.FavoriteTabReq\x1a*.bilibili.polymer.list.v1.FavoriteTabReply\x12\x66\n\x0c\x43heckAccount\x12).bilibili.polymer.list.v1.CheckAccountReq\x1a+.bilibili.polymer.list.v1.CheckAccountReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.list.v1.list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CHECKACCOUNTREPLY']._serialized_start=65
  _globals['_CHECKACCOUNTREPLY']._serialized_end=100
  _globals['_CHECKACCOUNTREQ']._serialized_start=102
  _globals['_CHECKACCOUNTREQ']._serialized_end=149
  _globals['_FAVORITETABITEM']._serialized_start=151
  _globals['_FAVORITETABITEM']._serialized_end=209
  _globals['_FAVORITETABREPLY']._serialized_start=211
  _globals['_FAVORITETABREPLY']._serialized_end=287
  _globals['_FAVORITETABREQ']._serialized_start=289
  _globals['_FAVORITETABREQ']._serialized_end=305
  _globals['_LIST']._serialized_start=308
  _globals['_LIST']._serialized_end=519
# @@protoc_insertion_point(module_scope)
